'use strict';

Object.defineProperty(exports, '__esModule', {
	value: true
});

var _toConsumableArray = function (arr) { if (Array.isArray(arr)) { for (var i = 0, arr2 = Array(arr.length); i < arr.length; i++) arr2[i] = arr[i]; return arr2; } else { return Array.from(arr); } };

exports['default'] = babelDedent;

function babelDedent(babel) {
	var t = babel.types;

	return new babel.Transformer('plugin-dedent', {
		CallExpression: function CallExpression(node) {
			if (t.isIdentifier(node.callee, { name: 'dedent' })) {
				if (t.isTemplateLiteral(node.arguments[0])) {
					transform(node.arguments[0].quasis);
					return node.arguments[0];
				} else if (t.isTaggedTemplateExpression(node.arguments[0])) {
					transform(node.arguments[0].quasi.quasis);
					return node.arguments[0];
				}
			}
		},
		TaggedTemplateExpression: function TaggedTemplateExpression(node) {
			if (t.isIdentifier(node.tag, { name: 'dedent' })) {
				transform(node.quasi.quasis);
				return node.quasi;
			}
		} });
}

function transform(quasis) {
	var elements = quasis.filter(function (element) {
		return element.type === 'TemplateElement';
	});
	var matches = [];
	var pattern = undefined;

	elements.forEach(function (element) {
		var match = element.value.raw.match(/\n[\t ]+/g);

		if (match) {
			matches.push.apply(matches, _toConsumableArray(match));
		}
	});

	if (matches.length) {
		var size = Math.min.apply(Math, _toConsumableArray(matches.map(function (value) {
			return value.length - 1;
		})));
		pattern = new RegExp('\n[\t ]{' + size + '}', 'g');
	}

	['raw', 'cooked'].forEach(function (type) {
		if (matches.length) {
			elements.forEach(function (element) {
				element.value[type] = element.value[type].replace(pattern, '\n');
			});
		}

		elements[0].value[type] = elements[0].value[type].replace(/^\r?\n/, '');
		elements[elements.length - 1].value[type] = elements[elements.length - 1].value[type].replace(/\r?\n$/, '');
	});
}
module.exports = exports['default'];